Index: main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/students/browser.py
===================================================================
--- main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/students/browser.py	(revision 12109)
+++ main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/students/browser.py	(revision 12120)
@@ -155,9 +155,9 @@
             form_fields = grok.AutoFields(INigeriaPGStudentClearance).omit(
             'clearance_locked', 'nysc_location', 'clr_code', 'officer_comment',
-            'date_of_invitation')
+            'physical_clearance_date')
         else:
             form_fields = grok.AutoFields(INigeriaUGStudentClearance).omit(
             'clearance_locked', 'clr_code', 'officer_comment',
-            'date_of_invitation')
+            'physical_clearance_date')
         return form_fields
 
Index: main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/students/interfaces.py
===================================================================
--- main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/students/interfaces.py	(revision 12109)
+++ main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/students/interfaces.py	(revision 12120)
@@ -68,6 +68,6 @@
         )
 
-    date_of_invitation= schema.TextLine(
-        title = _(u"Date of Invitation"),
+    physical_clearance_date= schema.TextLine(
+        title = _(u"Physical Clearance Date"),
         required = False,
         )
Index: main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/students/tests/test_export.py
===================================================================
--- main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/students/tests/test_export.py	(revision 12109)
+++ main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/students/tests/test_export.py	(revision 12120)
@@ -66,5 +66,5 @@
         self.assertMatches(
             'adm_code,alr_date,alr_fname,alr_no,alr_results,clearance_locked,'
-            'clr_code,date_of_birth,date_of_invitation,def_adm,disabled,email,emp2_end,'
+            'clr_code,date_of_birth,def_adm,disabled,email,emp2_end,'
             'emp2_position,emp2_reason,emp2_start,emp_end,emp_position,'
             'emp_reason,emp_start,employer,employer2,firstname,former_matric,'
@@ -76,13 +76,13 @@
             'next_kin_address,next_kin_name,next_kin_phone,next_kin_relation,'
             'nysc_lga,nysc_location,nysc_year,officer_comment,'
-            'perm_address,personal_updated,phone,reg_number,'
+            'perm_address,personal_updated,phone,physical_clearance_date,reg_number,'
             'religion,scd_sit_date,scd_sit_fname,scd_sit_no,'
             'scd_sit_results,scd_sit_type,sex,student_id,'
             'suspended,suspended_comment,password,state,history,certcode,is_postgrad,'
             'current_level,current_session\r\nmy adm code,,,,'
-            '"[(\'accounts\', \'A\')]",0,my clr code,1981-02-04#,,,,'
+            '"[(\'accounts\', \'A\')]",0,my clr code,1981-02-04#,,,'
             'anna@sample.com,,,,,,,,,,,Anna,,,,,"[(\'accounts\', \'A\')]"'
             ',,,,,,,,,,,,,,,,Tester,,,234,M.,NG,,,,,,,,,'
-            '"Studentroad 21\nLagos 123456\n",,+234-123-12345#,123,,,,,'
+            '"Studentroad 21\nLagos 123456\n",,+234-123-12345#,,123,,,,,'
             '"[(\'accounts\', \'A\')]",,f,A111111,0,,,created,'
             '[u\'2012-11-06 13:16:41 WAT - Record created by system\'],'
@@ -150,5 +150,5 @@
         # set values we can expect in export file
         self.setup_student(self.student)
-        self.student.date_of_invitation = 'Come soon'
+        self.student.physical_clearance_date = 'Come soon'
         IWorkflowState(self.student).setState('clearance requested')
         exporter = ClearanceRequestedStudentExporter()
@@ -157,5 +157,5 @@
         self.assertMatches(
             'student_id,reg_number,display_fullname,state,current_session,'
-            'history,date_of_invitation\r\n'
+            'history,physical_clearance_date\r\n'
             'A111111,123,Anna M. Tester,clearance requested,'
             '2012,2014-12-02 07:17:02 WAT - Record created by system,'

Index: main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/students/export.py
===================================================================
--- main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/students/export.py	(revision 12109)
+++ main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/students/export.py	(revision 12120)
@@ -89,5 +89,5 @@
 
 class ClearanceRequestedStudentExporter(StudentExporter):
     """Exporter of data used to assign dates of invitation
     """
 
@@ -95,5 +95,5 @@
 
     fields = ('student_id', 'reg_number', 'display_fullname',
-              'state', 'current_session', 'history', 'date_of_invitation')
+              'state', 'current_session', 'history', 'physical_clearance_date')
 
     title = _(u'Clearance Invitation Data')
@@ -89,5 +89,5 @@
 
 class ClearanceRequestedStudentExporter(StudentExporter):
-    """Exporter of data used to assign dates of invitation
+    """Exporter of data used to assign physical clearance dates.
     """
 